import React from 'react';
import { Button, Text } from 'native-base';
import { ViewStyle } from 'react-native';
import SmartComponent from '../SmartComponent';
import ImageWrapper from './ImageWrapper';

export interface Props {
  text: string,
  textColor?: string,
  color?: string,
  onPress : ()=>void,
  style? : ViewStyle,
  textSize? : number,
  iconRight? : {resource: number, style:ViewStyle},
  uppercase? : boolean,
}
export default class ButtonWrapper extends SmartComponent<Props> {

  render() {

    const { props } = this;

    const textColor = props.textColor || 'white';
    const text = props.text || '';
    const bgColor = props.color || 'white';
    const textSize = props.textSize || 15;

    return (
      <Button
        {...props}
        onPress={this.props.onPress}
        delayLongPress={20000}
        style={[{ backgroundColor: bgColor }, props.style]}
        block
      >
        <Text
          uppercase={props.uppercase}
          style={{ color: textColor, fontSize: textSize }}
        >
          {text}
        </Text>
        {
          this.props.iconRight ? (
            <ImageWrapper
              src={this.props.iconRight.resource}
              style={[{ marginTop: 'auto', marginBottom: 'auto' }, this.props.iconRight.style]}
            />
          ) : null
        }
      </Button>
    );
  }

}
