import React from 'react';
import { Text } from 'native-base';
import { TextProps, TextStyle } from 'react-native';
import SmartComponent from '../SmartComponent';

export interface Props extends TextProps{
    text: any,
    textColor?: any,
    backgroundColor?: any,
    textSize?: any,
    style? : TextStyle,
    shadow? : {size:number, radius:number},
    fontFamily? : string,
    uppercase? : boolean,
    textAlign? : 'auto' | 'left' | 'right' | 'center' | 'justify'
}
export default class TextWrapper extends SmartComponent<Props> {


    state={
      text: '',
    };

    constructor(props : Props) {
      super(props);
      this.state.text = props.text;
    }

    componentWillReceiveProps(nextProps, nextContext: any): void {
      this.state.text = nextProps.text;
    }

    setText(text : string) {
      this.state.text = text;
      this.forceUpdate();
    }

    render() {
      const { props } = this;

      const { text } = this.state;
      const textColor = props.textColor ? props.textColor : null;
      const backgroundColor = props.backgroundColor ? props.backgroundColor : null;
      const fontSize = props.textSize ? props.textSize : null;
      const shadow = props.shadow ? props.shadow : { size: 0, radius: 0 };

      if (props.textAlign === 'center') {
        if (!props.style) {
          props.style = {};
        }
        props.style.paddingRight = 'auto';
        props.style.paddingLeft = 'auto';
      }

      // ,textAlign: "center",textAlignVertical: "center"
      return (
        <Text
          {...props}
          style={[{
            textAlign: props.textAlign,
            fontFamily: props.fontFamily,
            fontSize,
            color: textColor,
            backgroundColor,
            textShadowColor: 'rgba(0, 0, 0, 0.75)',
            textShadowOffset: { width: -shadow.size, height: shadow.size },
            textShadowRadius: shadow.radius,
          }, props.style]}
        >
          {text}
        </Text>
      );
    }
}
